function c = CEMfieldcov(funch,M1,M2)
% Circulant embedding for fields in 2D
%
% Usage:
%   c = CEMfieldcov(funch,M1,M2)
% Inputs
%   funch     function handle for covariance
%   M1,M2     embedding domain size 
% Output
%   c         embedded covariance
%
% Spectrum for the embedded covariance is guaranteed
% to be real-valued if M1 and M2 are both odd integers. 
%
% This function does the circulant embedding in Chan and Wood algorithm
% in "Simulation of Stationary Gaussian Processes in [0,1]^d" (1994)
%
% If either M1 or M2 is an even integer, spectrum may
% not be real-valued (depends on whether covariance is
% 'even' in the corresponding coordinate -- see 
% Chan and Wood (1994))

% index mapping of h->htilde
htilde1 = zeros(1,M1); % init
M1intpart = floor(M1/2);
firstpart = 0:M1intpart;
secondpart = ((M1intpart+1):(M1-1)) - M1;
htilde1 = [firstpart secondpart];

htilde2 = zeros(1,M2); % init
M2intpart = floor(M2/2);
firstpart = 0:M2intpart;
secondpart = ((M2intpart+1):(M2-1)) - M2;
htilde2 = [firstpart secondpart];

[N1mesh,N2mesh] = meshgrid(htilde1,htilde2);

c = funch(N1mesh,N2mesh);

% Copyright (c), Hannes Helgason, KTH, 2011