% Demo for FindMaxSize.m

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% STEP 1: Define covariance structure
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
theta = 0.004;   
alpha = 1;
funch = @(n1,n2) poweredexp(n1,n2,theta,alpha);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% STEP 2: Set size for embedding domain
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
M = 2001; % NOTE: Currently only support square domains
disp(sprintf('Size of embedding domain: (M1,M2)=(%d,%d)',M,M));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% STEP 3: Find maximum possible size of synthesis domain for a fixed size
% of embedding domain. Here we use overlapping windows smoothing embedding.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
disp('Findimng maximum possible size of synthesis domain (this can take a while...)');
[Nmax,embeddingPossible] = FindMaxSize(funch,M);

% Exit early if embedding not possible:
if ~embeddingPossible,
    error(sprintf('Embedding not possible using overlapping window method for the given embedding size and covariance structure.'));
end
disp(sprintf('Maximum possible size of synthesis domain: (N1,N2)=(%d,%d)',Nmax,Nmax));


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% STEP 4: Embed covariance using overlapping windows
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
N1 = Nmax;
N2 = Nmax;
M1 = M;
M2 = M;
csmoothed = CEMOverlapWindow(funch,N1,N2,M1,M2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% STEP 5: SYNTHESIZE FIELD
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[X, Xiidcopy] = FieldSynth(csmoothed,N1,N2);
% X and Xiidcopy provide two independent
% realizations of the 2D field in a domain of size N1-by-N2


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% STEP 5: SOME PLOTTING
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot the realization
figure(1);
imagesc(X); colorbar; colormap(gray);
title('Realization of a 2D field');

% Plot the covariance
figure(2);
plotcov(funch,N1,N2)


% Hannes Helgason, KTH, September 2011