% Step-by-step demonstration of how to
% use the code to generate a 2D random field
%
% Hannes Helgason, KTH, September 2011

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% STEP 1: SET REQUESTED DOMAIN SIZE FOR SYNTHESIZED FIELD
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
N1 = 300;
N2 = N1; % NOTE: Currently only support square domains

disp(sprintf('Requested domain size N1=%d, N2=%d',N1,N2));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% STEP 2: DEFINE COVARIANCE STRUCTURE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
theta = 0.01;   
alpha = 1;
A = [1 1;0 1]; 
W = A'*A; % positive definite matrix
funch = @(n1,n2) poweredexpW(n1,n2,theta,alpha,W);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% STEP 3: EMBED COVARIANCE USING OVERLAPPING WINDOWS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
transRegLength = 320; % number of indices in each dimension
                      % for transition region
M1 = 2*N1 - 1 + transRegLength; % NOTE: Currently embedding domain has to be of odd integer size
M2 = M1; % NOTE: Currently only support square domains
csmoothed = CEMOverlapWindow(funch,N1,N2,M1,M2);

disp(sprintf('Embedding size M1=%d, M2=%d',M1,M2));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% STEP 4: SYNTHESIZE FIELD
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[X, Xiidcopy] = FieldSynth(csmoothed,N1,N2);
% X and Xiidcopy provide two independent
% realizations of the 2D field in a domain of size N1-by-N2


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% STEP 5: SOME PLOTTING
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot the realization
figure(1);
imagesc(X); colorbar; colormap(gray);
title('Realization of a 2D field');

% Plot the covariance
figure(2);
plotcov(funch,N1,N2)