function val = mollifier2D(t1,t2,epsilon)
% Mollifier function for a square domain
% (internal routine used by GenWindow.m)
%
% Usage:
%   val = mollifier2D(t1,t2,epsilon)
% Inputs
%   t1,t2    coordinates to evaluate ssat
%   epsilon  parameter controlling the mollifier support
%            Support is on a disc {(x,y) : x^2 + y^2 < epsilon^2}
% Output
%   val      equal to exp(-1/(1-|t1^2+t2^2|/epsilon^2)) if inside support
%            disc, otherwise equal to 0 

if nargin < 2,
    epsilon = 1;
end

val = zeros(size(t1));

tmp = sqrt(t1.^2 + t2.^2);
ind = and((tmp < epsilon),(tmp >-epsilon));

val(ind) = exp(-1./(1-abs(tmp(ind)/epsilon).^2))/epsilon;

% Copyright (c), Hannes Helgason, KTH, 2011
